@@ -1,19 +1,21 @@
+import builtins
 import functools
 import inspect
+import json
 import logging
 import sys
 
 from apigee import console
-from apigee.utils import remove_file_above_size, touch
+from apigee.utils import create_empty_file, remove_file_if_above_size
 
 
 class InvalidApisError(Exception):
     pass
 
 
-def setup_global_logger(log_file):
-    touch(log_file)
-    remove_file_above_size(log_file, size_kb=1000)
+def configure_global_logger(log_file):
+    create_empty_file(log_file)
+    remove_file_if_above_size(log_file, size_kb=1000)
     logging.basicConfig(
         filename=log_file,
         level=logging.WARNING,
@@ -21,7 +23,14 @@ def setup_global_logger(log_file):
     )
 
 
-def exception_handler(func):
+def log_and_echo_http_error(error, append_message=""):
+    error_message = f"Ignoring {type(error).__name__} {error.response.status_code} error{append_message}"
+    logging.warning(error_message)
+    console.echo(error_message)
+
+
+def wrap_with_exception_handling(func):
+
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
         try:
